import { AddressRecord, FormattedPremise, NumericExtractor, AddressElements, BuildingRangeMatch } from "./types";
import { Address } from "./index";
export declare const extract: (address: AddressRecord, elem: keyof AddressRecord) => string;
export declare const extractInteger: NumericExtractor;
export declare const isEmpty: (s: string) => boolean;
export declare const extractFloat: NumericExtractor;
/**
 * Non-desctructively return last elem
 */
export declare const lastElem: (a: AddressElements) => string;
export declare const prependLocality: (localities: AddressElements, premise: string) => void;
/**
 * Test for whether a string begins with a unit prefix
 *
 * E.g. `Back of 10A` => true
 */
export declare const hasUnitPrefix: (e: string) => boolean;
export declare const notEmpty: (a: string) => boolean;
/**
 * Exception Rule indicators:
 * i) First and last characters of the Building Name are numeric (eg ‘1to1’ or ’100:1’)
 * ii) First and penultimate characters are numeric, last character is alphabetic (eg 12A’)
 * iii) Building Name has only one character (eg ‘A’)
 */
export declare const nameException: (n: string) => boolean;
/**
 * Returns true if string matches rule (iii) of exception rule (above)
 */
export declare const isSingleCharacter: (c: string) => boolean;
export declare const appendOrganisationInfo: (elems: AddressElements, address: Address) => void;
/**
 * Merges premise elements ordered by precedence into a formatted address
 */
export declare const combinePremise: (elems: AddressElements, address: Address, premise: string, number: string, unit: string) => FormattedPremise;
/**
 * Detects whether a building name contains a range
 */
export declare const checkBuildingRange: (building_name: string) => BuildingRangeMatch | void;
/**
 * Returns an array of localities according to precedent recorded in
 * `localityElements`
 */
export declare const premiseLocalities: (address: Address) => AddressElements;
/**
 * Formats an address element
 * - If a single letter element, suffix a comma
 * - Otherwise return address element
 */
export declare const formatElem: (e: string) => string;
